*****************
Developer's Guide
*****************

This article describes the guidelines to be followed by developers working on this repository.
If you are planning on contributing to this repository please read the following carefully.
This guide borrows heavily from those developed by the SunPy Project and is generally consistent with this community-developed approach.


.. toctree::
   :maxdepth: 2

   dev_env
   code_standards
   tests
   docs
   maintainer_workflow
